# -*- coding: utf-8 -*-




# ========Convention: note the difference from PEP8 for variables!=============
# Naming:
#   * classes MixedUpperCase
#   * varables lowerUpper _or_ lower
#   * functions and methods underscore_separated _or_ lower
# =============================================================================

from __future__ import (absolute_import, division, print_function,
                        unicode_literals)
from maximus48.SSIM import *
from maximus48.var import *




__module__ = "maximus48"
__author__ = \
    "Maxim Polikarpov (European Molecular Laboratory Lab"
__email__ = "polikarpov.maxim@mail.ru"
__version__ = '0.1'
__date__ = "6 Aug 2018"
__license__ = "MIT license"




